@@ -11,7 +11,7 @@
 
 class TypeCode():
     """
-    Codes for the data types that can be converted using [[TypeConverter]].
+    Codes for the data types that can be converted using :class:`TypeConverter <pip_services3_commons.convert.TypeConverter.TypeConverter>`.
     """
     Unknown = 0
     String = 1
